@@ -2,7 +2,7 @@ import os
 import shutil
 import argparse
 
-__version__ = '1.0.7'
+__version__ = '1.1.0'
 
 
 def parse_args():
@@ -25,7 +25,6 @@ def dist_dir_check(dist_dir):
 
 
 def format_dir(root, project_name):
-    os.rename(os.path.join(root, 'project_name'), os.path.join(root, project_name))
     for fl in os.walk(root):
         dir, sub_dir, files = fl
         for file in files:
@@ -54,7 +53,6 @@ def main():
         if dist_dir_check(dist_dir, ):
             shutil.copytree(source_dir, dist_dir,
                             ignore=lambda src, names: [name for name in names if name == '__pycache__'])
-            format_dir(dist_dir, args.name)
             print(f'Create project at {dist_dir} Success!')
         else:
             print(f'The directory {dist_dir} was not empty, Can\'t create project.')
